//
//  Hex.swift
//  airbridge_flutter_sdk
//
//  Created by SangRyel Do on 3/11/24.
//

import Foundation

public class AirbridgeHex : NSObject {

    static func data(fromHexString string: String) -> Data? {
        // Convert the string to lowercase only once
        let string = string.lowercased()
        let length = string.count
        
        // Reserve capacity for the mutable data to avoid frequent reallocation
        var data = Data(capacity: length / 2)
        
        // Define constants for hex characters
        let hexCharacters: [Character] = Array("0123456789abcdef")
        
        for i in stride(from: 0, to: length, by: 2) {
            // Get two characters at once for better performance
            let highCharacter = string[string.index(string.startIndex, offsetBy: i)]
            let lowIndex = string.index(string.startIndex, offsetBy: i + 1)
            let lowCharacter = (lowIndex < string.endIndex) ? string[lowIndex] : "0"
            
            // Convert hex characters to bytes
            if 
                let highCharacterIndex = hexCharacters.firstIndex(of: highCharacter),
                let lowCharacterIndex = hexCharacters.firstIndex(of: lowCharacter) 
            {
                // Calculate the byte from the hex characters
                let byte: UInt8 = UInt8(highCharacterIndex) << 4 | UInt8(lowCharacterIndex)
                
                // Append the byte to the data
                data.append(byte)
            } else {
                return nil  
            }
        }
        
        return data
    }
}
